@@ -17,14 +17,15 @@ def _setup_joins_for_fields(parts, node, queryset):
     if parts_num == 1:
         node.field = (queryset.model._meta.db_table, parts[0])
 
-    setup_joins = queryset.query.setup_joins(
-        parts, queryset.model._meta, queryset.query.get_initial_alias(), False)
-
+    setup_joins_args = (parts, queryset.model._meta,
+                        queryset.query.get_initial_alias())
     if version_gt_1_5:
         # Django 1.6+ compatibility.
-        field, source, opts, join_list, last = setup_joins
+        field, source, opts, join_list, last = queryset.query.setup_joins(
+            *setup_joins_args)
     else:
-        field, source, opts, join_list, last, _ = setup_joins
+        field, source, opts, join_list, last, _ = queryset.query.setup_joins(
+            *setup_joins_args, dupe_multis=False)
 
     # Process the join chain to see if it can be trimmed
     if version_gt_1_5:
